@@ -3,7 +3,7 @@ from typing import Any, Dict
 import xgboost as xgb
 
 from .model_management import ModelManager
-from ..core import CustomNamedTemporaryFile
+from ..core.file_management import CustomNamedTemporaryFile
 
 
 class XGBoostModelManager(ModelManager):
